@@ -1,4 +1,8 @@
-from sqlalchemy import Column, Integer, String, Float, Boolean, ForeignKey, Date, DateTime
+"""
+Роли и пользовали внутри Univer
+"""
+
+from sqlalchemy import Column, Integer, String, ForeignKey, DateTime
 from sqlalchemy.orm import relationship, backref, validates
 
 from univer_db.orm import get_base
@@ -31,7 +35,7 @@ class User(Base):
     access = Column('user_access', Integer, default=0)
 
     def __repr__(self):
-        return '<User {} (id={})>'.format(self, self.id)
+        return f'<User {self} (id={self.id})>'
 
     def __str__(self):
         return self.username
@@ -53,7 +57,7 @@ class Student(Base):
     status = Column('status', Integer)
 
     @validates('status')
-    def validate_status(self, key, value):
+    def validate_status(self, key, value):  # pylint: disable=unused-argument
         """
         Значением status могут быть следующие значения:
         - 1 (Активный)
@@ -152,7 +156,7 @@ class Student(Base):
     sex = Column('students_sex', Integer)
 
     @validates('sex')
-    def validate_sex(self, key, value):
+    def validate_sex(self, key, value):  # pylint: disable=unused-argument
         """
         Значением sex могут быть следующие значения:
         - 1 (Мужчина)
@@ -164,7 +168,7 @@ class Student(Base):
     marital_status = Column('students_marital_status', Integer)
 
     @validates('marital_status')
-    def validate_marital_status(self, key, value):
+    def validate_marital_status(self, key, value):  # pylint: disable=unused-argument
         """
         Значением marital_status могут быть следующие значения:
         - 0 (Не женат/Не замужена)
@@ -178,6 +182,9 @@ class Student(Base):
         'univer_student_edu_statuses.student_edu_status_id'))
     edu_status = relationship('EduStatus')
 
+    # Мобильный телефон
+    mobile_phone = Column('students_mobile_phone', String(50))
+
     # ФИО студента в дательном падеже (На русском языке)
     dative_last_name_ru = Column('students_dative_sname_ru', String(100))
     dative_first_name_ru = Column('students_dative_name_ru', String(100))
@@ -235,6 +242,9 @@ class Student(Base):
 
     @property
     def payment_info_ru(self):
+        """
+        Возвращает специальный текст на русском для формы оплаты
+        """
         if self.payment_form_id == 2:
             return 'на платной основе'
         elif self.payment_form_id == 5:
@@ -242,6 +252,9 @@ class Student(Base):
 
     @property
     def payment_info_kz(self):
+        """
+        Возвращает специальный текст на казахском для формы оплаты
+        """
         if self.payment_form_id == 2:
             return 'ақылы негізде'
         elif self.payment_form_id == 5:
@@ -249,41 +262,73 @@ class Student(Base):
 
     @property
     def edu_level_info_ru(self):
+        """
+        Возвращает специальный текст на русском для уровня образования
+        """
         if self.edu_level_id == 1:
             return '(бакалавриат, 4 года)'
         elif self.edu_level_id == 3:
-            return 'по сокращенной образовательной программе на базе среднего профессионального образования'
+            return 'по сокращенной образовательной программе на ' \
+                'базе среднего профессионального образования'
         elif self.edu_level_id == 2:
             return 'по сокращенной образовательной программе на базе высшего образования'
 
     @property
     def edu_level_info_kz(self):
+        """
+        Возвращает специальный текст на казахском для уровня образования
+        """
         if self.edu_level_id == 1:
             return '(бакалавриат, 4 жыл)'
         elif self.edu_level_id == 3:
-            return 'орта кәсіптік білім негізінде қысқартылған білім беру бағдарламасы бойынша күндізгі білім беру нысаны'
+            return 'орта кәсіптік білім негізінде қысқартылған білім беру ' \
+                'бағдарламасы бойынша күндізгі білім беру нысаны'
         elif self.edu_level_id == 2:
-            return 'жоғары білім негізінде қысқартылған білім беру бағдарламасы бойынша күндізгі білім беру нысаны'
+            return 'жоғары білім негізінде қысқартылған білім беру ' \
+                'бағдарламасы бойынша күндізгі білім беру нысаны'
 
     @property
     def dative_full_name_ru(self):
-        dative_last_name_ru = self.dative_last_name_ru if self.dative_last_name_ru else self.last_name
-        dative_first_name_ru = self.dative_first_name_ru if self.dative_first_name_ru else self.first_name
-        dative_middle_name_ru = self.dative_middle_name_ru if self.dative_middle_name_ru else self.middle_name
+        """
+        Возвращает ФИО в дательном падеже (На русском)
+        """
+        last_name = self.dative_last_name_ru if self.dative_last_name_ru else self.last_name
+        first_name = self.dative_first_name_ru if self.dative_first_name_ru else self.first_name
+        middle_name = self.dative_middle_name_ru if self.dative_middle_name_ru else self.middle_name
 
-        return ' '.join(filter(None, [dative_last_name_ru, dative_first_name_ru, dative_middle_name_ru]))
+        return ' '.join(filter(None, [last_name, first_name, middle_name]))
 
     @property
     def dative_full_name_kz(self):
-        dative_last_name_kz = self.dative_last_name_kz if self.dative_last_name_kz else self.last_name
-        dative_first_name_kz = self.dative_first_name_kz if self.dative_first_name_kz else self.first_name
-        dative_middle_name_kz = self.dative_middle_name_kz if self.dative_middle_name_kz else self.middle_name
+        """
+        Возвращает ФИО в дательном падеже (На казахском)
+        """
+        last_name = self.dative_last_name_kz if self.dative_last_name_kz else self.last_name
+        first_name = self.dative_first_name_kz if self.dative_first_name_kz else self.first_name
+        middle_name = self.dative_middle_name_kz if self.dative_middle_name_kz else self.middle_name
 
-        return ' '.join(filter(None, [dative_last_name_kz, dative_first_name_kz, dative_middle_name_kz]))
+        return ' '.join(
+            filter(
+                None,
+                [last_name, first_name, middle_name]
+            )
+        )
 
     @property
     def dative_full_name_en(self):
-        return ' '.join(filter(None, [self.dative_last_name_en, self.dative_first_name_en, self.dative_middle_name_en]))
+        """
+        Возвращает ФИО в дательном падеже (На английском)
+        """
+        return ' '.join(
+            filter(
+                None,
+                [
+                    self.dative_last_name_en,
+                    self.dative_first_name_en,
+                    self.dative_middle_name_en
+                ]
+            )
+        )
 
     def __repr__(self):
         return f'<Student {self} (id={self.id} user={self.user_id} status={self.status})>'
@@ -382,7 +427,7 @@ class Personnel(Base):
     status = Column(Integer)
 
     def __repr__(self):
-        return '<Personnel {} (id={} user={} status={})>'.format(self, self.user_id, self.status)
+        return f'<Personnel {self} (id={self.id} user={self.user_id} status={self.status})>'
 
     def __str__(self):
         return ' '.join(filter(None, [self.last_name, self.first_name, self.middle_name]))
@@ -408,7 +453,7 @@ class Teacher(Base):
     status = Column('status', Integer)
 
     def __repr__(self):
-        return '<Teacher {} (id={} personnel={} status={})>'.format(self, self.id, self.personnel_id, self.status)
+        return f'<Teacher {self} (id={self.id} personnel={self.personnel_id} status={self.status})>'
 
     def __str__(self):
         return str(self.personnel)
@@ -440,7 +485,7 @@ class OfficeRegistrator(Base):
     type = Column(Integer)
 
     def __repr__(self):
-        return '<OfficeRegistrator {} (id={})>'.format(self, self.id)
+        return f'<OfficeRegistrator {self} (id={self.id})>'
 
     def __str__(self):
         return str(self.personnel)
@@ -463,7 +508,7 @@ class OfficeRegistratorFacultyLink(Base):
     faculty = relationship('Faculty')
 
     def __repr__(self):
-        return '<OfficeRegistratorFacultyLink {}>'.format(self)
+        return f'<OfficeRegistratorFacultyLink {self}>'
 
     def __str__(self):
         return f'{self.office_registrator}: {self.faculty}'
@@ -497,7 +542,7 @@ class ChairHead(Base):
     status = Column(Integer)
 
     def __repr__(self):
-        return '<ChairHead {} (id={} status={})'.format(self, self.id, self.status)
+        return f'<ChairHead {self} (id={self.id} status={self.status})>'
 
     def __str__(self):
         return f'{self.personnel}: {self.chair}'
@@ -531,7 +576,7 @@ class Dean(Base):
     status = Column(Integer)
 
     def __repr__(self):
-        return '<Dean {} (id={})>'.format(self, self.id)
+        return f'<Dean {self} (id={self.id})>'
 
     def __str__(self):
         return str(self.personnel)
@@ -556,7 +601,7 @@ class TeacherChairLink(Base):
     rate = Column('stavka', Integer)
 
     def __repr__(self):
-        return '<TeacherChairLink {}>'.format(self)
+        return f'<TeacherChairLink {self}>'
 
     def __str__(self):
         return f'{self.chair}: {self.teacher}'
@@ -588,7 +633,7 @@ class Adviser(Base):
     chair = relationship('Chair')
 
     def __repr__(self):
-        return '<Adviser {}>'.format(self)
+        return f'<Adviser {self}>'
 
     def __str__(self):
         return str(self.personnel)
@@ -613,7 +658,7 @@ class AdviserStudent(Base):
         'Student', backref=backref('advisers', lazy='dynamic'))
 
     def __repr__(self):
-        return '<AdviserStudent {}>'.format(self)
+        return f'<AdviserStudent {self}>'
 
     def __str__(self):
         return f'{self.adviser}: {self.student}'
